@@ -1,22 +1,22 @@
-# -*- coding: utf-8 -*-
-from .common import PyEXception, PyEXStopSSE, overrideSSEUrl, overrideUrl, setProxy
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 from .client import *  # noqa: F403
+from .common import PyEXception, PyEXStopSSE, overrideSSEUrl, overrideUrl, setProxy
 
 try:
     from .studies import *  # noqa: F403
 except ImportError:
     pass
 
+from ._version import __version__
 from .account import *  # noqa: F403
-from .alternative import (
-    crypto,
-    cryptoDF,
-    sentiment,
-    sentimentDF,
-    ceoCompensation,
-    ceoCompensationDF,
-)
-from .commodities import CommoditiesPoints
+from .alternative import ceoCompensation, ceoCompensationDF, sentiment, sentimentDF
+from .commodities import *
 from .cryptocurrency import (
     cryptoBook,
     cryptoBookDF,
@@ -25,121 +25,17 @@ from .cryptocurrency import (
     cryptoQuote,
     cryptoQuoteDF,
 )
-from .economic import EconomicPoints
+from .economic import *
 from .fx import (
-    latestFX,
-    latestFXDF,
     convertFX,
     convertFXDF,
     historicalFX,
     historicalFXDF,
+    latestFX,
+    latestFXDF,
 )
 from .markets import markets, marketsDF
-from .marketdata.cryptocurrency import (
-    cryptoBookSSE,
-    cryptoBookSSEAsync,
-    cryptoEventsSSE,
-    cryptoEventsSSEAsync,
-    cryptoQuotesSSE,
-    cryptoQuotesSSEAsync,
-)
-from .marketdata.fx import (
-    fxSSE,
-    fxSSEAsync,
-    forex1SecondSSE,
-    forex1SecondSSEAsync,
-    forex5SecondSSE,
-    forex5SecondSSEAsync,
-    forex1MinuteSSE,
-    forex1MinuteSSEAsync,
-)
-from .marketdata.news import newsSSE, newsSSEAsync
-from .marketdata.sentiment import sentimentSSE, sentimentSSEAsync
-from .marketdata.sse import (
-    topsSSE,
-    topsSSEAsync,
-    lastSSE,
-    lastSSEAsync,
-    deepSSE,
-    deepSSEAsync,
-    tradesSSE,
-    tradesSSEAsync,
-    auctionSSE,
-    auctionSSEAsync,
-    bookSSE,
-    bookSSEAsync,
-    opHaltStatusSSE,
-    opHaltStatusSSEAsync,
-    officialPriceSSE,
-    officialPriceSSEAsync,
-    securityEventSSE,
-    securityEventSSEAsync,
-    ssrStatusSSE,
-    ssrStatusSSEAsync,
-    systemEventSSE,
-    systemEventSSEAsync,
-    tradeBreaksSSE,
-    tradeBreaksSSEAsync,
-    tradingStatusSSE,
-    tradingStatusSSEAsync,
-)
-from .marketdata.stock import (
-    stocksUSNoUTPSSE,
-    stocksUSNoUTPSSEAsync,
-    stocksUSSSE,
-    stocksUSSSEAsync,
-    stocksUS1SecondSSE,
-    stocksUS1SecondSSEAsync,
-    stocksUS5SecondSSE,
-    stocksUS5SecondSSEAsync,
-    stocksUS1MinuteSSE,
-    stocksUS1MinuteSSEAsync,
-)
-from .marketdata.http import (
-    tops,
-    topsAsync,
-    topsDF,
-    last,
-    lastAsync,
-    lastDF,
-    deep,
-    deepAsync,
-    deepDF,
-    hist,
-    histAsync,
-    histDF,
-    trades,
-    tradesAsync,
-    tradesDF,
-    auction,
-    auctionAsync,
-    auctionDF,
-    book as deepBook,
-    bookAsync as deepBookAsync,
-    bookDF as deepBookDF,
-    opHaltStatus,
-    opHaltStatusAsync,
-    opHaltStatusDF,
-    officialPrice,
-    officialPriceAsync,
-    officialPriceDF,
-    securityEvent,
-    securityEventAsync,
-    securityEventDF,
-    ssrStatus,
-    ssrStatusAsync,
-    ssrStatusDF,
-    systemEvent,
-    systemEventAsync,
-    systemEventDF,
-    tradeBreak,
-    tradeBreakAsync,
-    tradeBreakDF,
-    tradingStatus,
-    tradingStatusAsync,
-    tradingStatusDF,
-)
-from .marketdata.ws import *  # noqa: F403
+from .options import optionExpirations, options, optionsDF
 from .points import points, pointsDF
 from .premium import (
     accountingQualityAndRiskMatrix,
@@ -148,27 +44,27 @@ from .premium import (
     analystDaysDF,
     boardOfDirectorsMeeting,
     boardOfDirectorsMeetingDF,
-    brain30DaySentiment,
-    brain30DaySentimentDF,
-    brain7DaySentiment,
-    brain7DaySentimentDF,
-    brain21DayMLReturnRanking,
-    brain21DayMLReturnRankingDF,
-    brain10DayMLReturnRanking,
-    brain10DayMLReturnRankingDF,
-    brain5DayMLReturnRanking,
-    brain5DayMLReturnRankingDF,
-    brain3DayMLReturnRanking,
-    brain3DayMLReturnRankingDF,
     brain2DayMLReturnRanking,
     brain2DayMLReturnRankingDF,
+    brain3DayMLReturnRanking,
+    brain3DayMLReturnRankingDF,
+    brain5DayMLReturnRanking,
+    brain5DayMLReturnRankingDF,
+    brain7DaySentiment,
+    brain7DaySentimentDF,
+    brain10DayMLReturnRanking,
+    brain10DayMLReturnRankingDF,
+    brain21DayMLReturnRanking,
+    brain21DayMLReturnRankingDF,
+    brain30DaySentiment,
+    brain30DaySentimentDF,
+    brainLanguageMetricsOnCompanyFilings,
     brainLanguageMetricsOnCompanyFilingsAll,
     brainLanguageMetricsOnCompanyFilingsAllDF,
-    brainLanguageMetricsOnCompanyFilings,
     brainLanguageMetricsOnCompanyFilingsDF,
+    brainLanguageMetricsOnCompanyFilingsDifference,
     brainLanguageMetricsOnCompanyFilingsDifferenceAll,
     brainLanguageMetricsOnCompanyFilingsDifferenceAllDF,
-    brainLanguageMetricsOnCompanyFilingsDifference,
     brainLanguageMetricsOnCompanyFilingsDifferenceDF,
     businessUpdates,
     businessUpdatesDF,
@@ -221,9 +117,9 @@ from .premium import (
     iposWSH,
     iposWSHDF,
     kScore,
-    kScoreDF,
     kScoreChina,
     kScoreChinaDF,
+    kScoreDF,
     legalActions,
     legalActionsDF,
     mergersAndAcquisitions,
@@ -232,8 +128,8 @@ from .premium import (
     nonTimelyFilingsDF,
     precisionAlphaPriceDynamics,
     precisionAlphaPriceDynamicsDF,
-    productEventsDF,
     productEvents,
+    productEventsDF,
     researchAndDevelopmentDays,
     researchAndDevelopmentDaysDF,
     sameStoreSales,
@@ -252,83 +148,77 @@ from .premium import (
     tacticalModel1DF,
     tradeShows,
     tradeShowsDF,
+    valuEngineStockResearchReport,
     witchingHours,
     witchingHoursDF,
-    valuEngineStockResearchReport,
     workshops,
     workshopsDF,
 )
 from .rates import RatesPoints
 from .refdata import (
-    symbols,
-    iexSymbols,
-    mutualFundSymbols,
-    otcSymbols,
-    internationalSymbols,
-    fxSymbols,
-    optionsSymbols,
-    cryptoSymbols,
-    symbolsDF,
-    iexSymbolsDF,
-    mutualFundSymbolsDF,
-    otcSymbolsDF,
-    internationalSymbolsDF,
-    fxSymbolsDF,
-    optionsSymbolsDF,
-    cryptoSymbolsDF,
-    symbolsList,
-    iexSymbolsList,
-    mutualFundSymbolsList,
-    otcSymbolsList,
-    internationalSymbolsList,
-    fxSymbolsList,
-    optionsSymbolsList,
-    cryptoSymbolsList,
-    corporateActions,
-    corporateActionsDF,
-    refDividends,
-    refDividendsDF,
-    nextDayExtDate,
-    nextDayExtDateDF,
-    directory,
-    directoryDF,
     calendar,
     calendarDF,
-    holidays,
-    holidaysDF,
+    corporateActions,
+    corporateActionsDF,
+    cryptoSymbols,
+    cryptoSymbolsDF,
+    cryptoSymbolsList,
+    directory,
+    directoryDF,
     exchanges,
     exchangesDF,
+    fxSymbols,
+    fxSymbolsDF,
+    fxSymbolsList,
+    holidays,
+    holidaysDF,
+    iexSymbols,
+    iexSymbolsDF,
+    iexSymbolsList,
     internationalExchanges,
     internationalExchangesDF,
-    sectors,
-    sectorsDF,
+    internationalSymbols,
+    internationalSymbolsDF,
+    internationalSymbolsList,
+    mutualFundSymbols,
+    mutualFundSymbolsDF,
+    mutualFundSymbolsList,
+    nextDayExtDate,
+    nextDayExtDateDF,
+    optionsSymbols,
+    optionsSymbolsDF,
+    optionsSymbolsList,
+    otcSymbols,
+    otcSymbolsDF,
+    otcSymbolsList,
+    refDividends,
+    refDividendsDF,
     search,
     searchDF,
+    sectors,
+    sectorsDF,
+    symbols,
+    symbolsDF,
+    symbolsList,
     tags,
     tagsDF,
 )
-from .rules import (
-    schema,
-    create,
-    lookup,
-    pause,
-    resume,
-    delete,
-    rule as ruleInfo,
-    rules,
-    output as ruleOutput,
-)
+from .rules import create, delete, lookup
+from .rules import output as ruleOutput
+from .rules import pause, resume
+from .rules import rule as ruleInfo
+from .rules import rules, schema
 from .stats import (
-    stats,
-    statsDF,
+    daily,
+    dailyDF,
     recent,
     recentDF,
     records,
     recordsDF,
+    stats,
+    statsDF,
     summary,
     summaryDF,
-    daily,
-    dailyDF,
 )
 from .stocks import (
     advancedStats,
@@ -339,30 +229,30 @@ from .stocks import (
     balanceSheetDF,
     batch,
     batchDF,
-    bulkBatch,
-    bulkBatchDF,
-    book,
-    bookDF,
     bonusIssue,
     bonusIssueDF,
+    book,
+    bookDF,
+    bulkBatch,
+    bulkBatchDF,
     bulkMinuteBars,
     bulkMinuteBarsDF,
     cashFlow,
     cashFlowDF,
     chart,
     chartDF,
-    company,
-    companyDF,
     collections,
     collectionsDF,
+    company,
+    companyDF,
     delayedQuote,
     delayedQuoteDF,
     distribution,
     distributionDF,
     dividends,
     dividendsBasic,
-    dividendsDF,
     dividendsBasicDF,
+    dividendsDF,
     earnings,
     earningsDF,
     earningsToday,
@@ -371,10 +261,52 @@ from .stocks import (
     estimatesDF,
     financials,
     financialsDF,
-    fundOwnership,
-    fundOwnershipDF,
     fundamentals,
     fundamentalsDF,
+    fundOwnership,
+    fundOwnershipDF,
+    iexAuction,
+    iexAuctionAsync,
+    iexAuctionDF,
+    iexBook,
+    iexBookAsync,
+    iexBookDF,
+    iexDeep,
+    iexDeepAsync,
+    iexDeepDF,
+    iexHist,
+    iexHistAsync,
+    iexHistDF,
+    iexLast,
+    iexLastAsync,
+    iexLastDF,
+    iexOfficialPrice,
+    iexOfficialPriceAsync,
+    iexOfficialPriceDF,
+    iexOpHaltStatus,
+    iexOpHaltStatusAsync,
+    iexOpHaltStatusDF,
+    iexSecurityEvent,
+    iexSecurityEventAsync,
+    iexSecurityEventDF,
+    iexSsrStatus,
+    iexSsrStatusAsync,
+    iexSsrStatusDF,
+    iexSystemEvent,
+    iexSystemEventAsync,
+    iexSystemEventDF,
+    iexTops,
+    iexTopsAsync,
+    iexTopsDF,
+    iexTradeBreak,
+    iexTradeBreakAsync,
+    iexTradeBreakDF,
+    iexTrades,
+    iexTradesAsync,
+    iexTradesDF,
+    iexTradingStatus,
+    iexTradingStatusAsync,
+    iexTradingStatusDF,
     incomeStatement,
     incomeStatementDF,
     insiderRoster,
@@ -391,10 +323,6 @@ from .stocks import (
     ipoTodayDF,
     ipoUpcoming,
     ipoUpcomingDF,
-    marketShortInterest,
-    marketShortInterestDF,
-    marketVolume,
-    marketVolumeDF,
     keyStats,
     keyStatsDF,
     largestTrades,
@@ -402,20 +330,28 @@ from .stocks import (
     list,
     listDF,
     logo,
-    logoPNG,
     logoNotebook,
-    news,
-    newsDF,
+    logoPNG,
     marketNews,
     marketNewsDF,
-    ohlc,
-    ohlcDF,
     marketOhlc,
     marketOhlcDF,
-    peers,
-    peersDF,
+    marketPrevious,
+    marketPreviousDF,
+    marketShortInterest,
+    marketShortInterestDF,
+    marketVolume,
+    marketVolumeDF,
     marketYesterday,
     marketYesterdayDF,
+    news,
+    newsDF,
+    ohlc,
+    ohlcDF,
+    peers,
+    peersDF,
+    previous,
+    previousDF,
     price,
     priceDF,
     priceTarget,
@@ -438,33 +374,92 @@ from .stocks import (
     securitySwapDF,
     shortInterest,
     shortInterestDF,
-    splits,
-    splitsDF,
     spinoff,
     spinoffDF,
+    splits,
+    splitsDF,
     spread,
     spreadDF,
     stockSplits,
     stockSplitsDF,
     threshold,
     thresholdDF,
-    upcomingEvents,
-    upcomingEventsDF,
-    upcomingEarnings,
-    upcomingEarningsDF,
     upcomingDividends,
     upcomingDividendsDF,
-    upcomingSplits,
-    upcomingSplitsDF,
+    upcomingEarnings,
+    upcomingEarningsDF,
+    upcomingEvents,
+    upcomingEventsDF,
     upcomingIPOs,
     upcomingIPOsDF,
+    upcomingSplits,
+    upcomingSplitsDF,
     volumeByVenue,
     volumeByVenueDF,
     yesterday,
     yesterdayDF,
 )
-from .options import optionExpirations, options, optionsDF
-from ._version import __version__
+from .streaming.cryptocurrency import (
+    cryptoBookSSE,
+    cryptoBookSSEAsync,
+    cryptoEventsSSE,
+    cryptoEventsSSEAsync,
+    cryptoQuotesSSE,
+    cryptoQuotesSSEAsync,
+)
+from .streaming.fx import (
+    forex1MinuteSSE,
+    forex1MinuteSSEAsync,
+    forex1SecondSSE,
+    forex1SecondSSEAsync,
+    forex5SecondSSE,
+    forex5SecondSSEAsync,
+    fxSSE,
+    fxSSEAsync,
+)
+from .streaming.news import newsSSE, newsSSEAsync
+from .streaming.sentiment import sentimentSSE, sentimentSSEAsync
+from .streaming.sse import (
+    iexAuctionSSE,
+    iexAuctionSSEAsync,
+    iexBookSSE,
+    iexBookSSEAsync,
+    iexDeepSSE,
+    iexDeepSSEAsync,
+    iexLastSSE,
+    iexLastSSEAsync,
+    iexOfficialPriceSSE,
+    iexOfficialPriceSSEAsync,
+    iexOpHaltStatusSSE,
+    iexOpHaltStatusSSEAsync,
+    iexSecurityEventSSE,
+    iexSecurityEventSSEAsync,
+    iexSsrStatusSSE,
+    iexSsrStatusSSEAsync,
+    iexSystemEventSSE,
+    iexSystemEventSSEAsync,
+    iexTopsSSE,
+    iexTopsSSEAsync,
+    iexTradeBreaksSSE,
+    iexTradeBreaksSSEAsync,
+    iexTradesSSE,
+    iexTradesSSEAsync,
+    iexTradingStatusSSE,
+    iexTradingStatusSSEAsync,
+)
+from .streaming.stock import (
+    stocksUS1MinuteSSE,
+    stocksUS1MinuteSSEAsync,
+    stocksUS1SecondSSE,
+    stocksUS1SecondSSEAsync,
+    stocksUS5SecondSSE,
+    stocksUS5SecondSSEAsync,
+    stocksUSNoUTPSSE,
+    stocksUSNoUTPSSEAsync,
+    stocksUSSSE,
+    stocksUSSSEAsync,
+)
+from .streaming.ws import *  # noqa: F403
 
 try:
     from .caching import *  # noqa: F403
