@@ -1,17 +1,17 @@
-# -*- coding: utf-8 -*-
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 import os
 from functools import partial, wraps
-from .common import PyEXception, _interval
+
 from .account import messageBudget, metadata, metadataDF, usage, usageDF
-from .alternative import (
-    crypto,
-    cryptoDF,
-    sentiment,
-    sentimentDF,
-    ceoCompensation,
-    ceoCompensationDF,
-)
+from .alternative import ceoCompensation, ceoCompensationDF, sentiment, sentimentDF
 from .commodities import CommoditiesPoints
+from .common import PyEXception, _interval
 from .cryptocurrency import (
     cryptoBook,
     cryptoBookDF,
@@ -22,100 +22,15 @@ from .cryptocurrency import (
 )
 from .economic import EconomicPoints
 from .fx import (
-    latestFX,
-    latestFXDF,
     convertFX,
     convertFXDF,
     historicalFX,
     historicalFXDF,
+    latestFX,
+    latestFXDF,
 )
 from .markets import markets, marketsDF
-from .marketdata.cryptocurrency import (
-    cryptoBookSSE,
-    cryptoBookSSEAsync,
-    cryptoEventsSSE,
-    cryptoEventsSSEAsync,
-    cryptoQuotesSSE,
-    cryptoQuotesSSEAsync,
-)
-from .marketdata.fx import (
-    fxSSE,
-    fxSSEAsync,
-    forex1SecondSSE,
-    forex1SecondSSEAsync,
-    forex5SecondSSE,
-    forex5SecondSSEAsync,
-    forex1MinuteSSE,
-    forex1MinuteSSEAsync,
-)
-from .marketdata.news import newsSSE, newsSSEAsync
-from .marketdata.sentiment import sentimentSSE, sentimentSSEAsync
-from .marketdata.sse import (
-    topsSSE,
-    topsSSEAsync,
-    lastSSE,
-    lastSSEAsync,
-    deepSSE,
-    deepSSEAsync,
-    tradesSSE,
-    tradesSSEAsync,
-)
-from .marketdata.stock import (
-    stocksUSNoUTPSSE,
-    stocksUSNoUTPSSEAsync,
-    stocksUSSSE,
-    stocksUSSSEAsync,
-    stocksUS1SecondSSE,
-    stocksUS1SecondSSEAsync,
-    stocksUS5SecondSSE,
-    stocksUS5SecondSSEAsync,
-    stocksUS1MinuteSSE,
-    stocksUS1MinuteSSEAsync,
-)
-from .marketdata.http import (
-    tops,
-    topsAsync,
-    topsDF,
-    last,
-    lastAsync,
-    lastDF,
-    deep,
-    deepAsync,
-    deepDF,
-    hist,
-    histAsync,
-    histDF,
-    trades,
-    tradesAsync,
-    tradesDF,
-    auction,
-    auctionAsync,
-    auctionDF,
-    book as deepBook,
-    bookAsync as deepBookAsync,
-    bookDF as deepBookDF,
-    opHaltStatus,
-    opHaltStatusAsync,
-    opHaltStatusDF,
-    officialPrice,
-    officialPriceAsync,
-    officialPriceDF,
-    securityEvent,
-    securityEventAsync,
-    securityEventDF,
-    ssrStatus,
-    ssrStatusAsync,
-    ssrStatusDF,
-    systemEvent,
-    systemEventAsync,
-    systemEventDF,
-    tradeBreak,
-    tradeBreakAsync,
-    tradeBreakDF,
-    tradingStatus,
-    tradingStatusAsync,
-    tradingStatusDF,
-)
+from .options import optionExpirations, options, optionsDF
 from .points import points, pointsDF
 from .premium import (
     accountingQualityAndRiskMatrix,
@@ -124,27 +39,27 @@ from .premium import (
     analystDaysDF,
     boardOfDirectorsMeeting,
     boardOfDirectorsMeetingDF,
-    brain30DaySentiment,
-    brain30DaySentimentDF,
-    brain7DaySentiment,
-    brain7DaySentimentDF,
-    brain21DayMLReturnRanking,
-    brain21DayMLReturnRankingDF,
-    brain10DayMLReturnRanking,
-    brain10DayMLReturnRankingDF,
-    brain5DayMLReturnRanking,
-    brain5DayMLReturnRankingDF,
-    brain3DayMLReturnRanking,
-    brain3DayMLReturnRankingDF,
     brain2DayMLReturnRanking,
     brain2DayMLReturnRankingDF,
+    brain3DayMLReturnRanking,
+    brain3DayMLReturnRankingDF,
+    brain5DayMLReturnRanking,
+    brain5DayMLReturnRankingDF,
+    brain7DaySentiment,
+    brain7DaySentimentDF,
+    brain10DayMLReturnRanking,
+    brain10DayMLReturnRankingDF,
+    brain21DayMLReturnRanking,
+    brain21DayMLReturnRankingDF,
+    brain30DaySentiment,
+    brain30DaySentimentDF,
+    brainLanguageMetricsOnCompanyFilings,
     brainLanguageMetricsOnCompanyFilingsAll,
     brainLanguageMetricsOnCompanyFilingsAllDF,
-    brainLanguageMetricsOnCompanyFilings,
     brainLanguageMetricsOnCompanyFilingsDF,
+    brainLanguageMetricsOnCompanyFilingsDifference,
     brainLanguageMetricsOnCompanyFilingsDifferenceAll,
     brainLanguageMetricsOnCompanyFilingsDifferenceAllDF,
-    brainLanguageMetricsOnCompanyFilingsDifference,
     brainLanguageMetricsOnCompanyFilingsDifferenceDF,
     businessUpdates,
     businessUpdatesDF,
@@ -197,9 +112,9 @@ from .premium import (
     iposWSH,
     iposWSHDF,
     kScore,
-    kScoreDF,
     kScoreChina,
     kScoreChinaDF,
+    kScoreDF,
     legalActions,
     legalActionsDF,
     mergersAndAcquisitions,
@@ -208,8 +123,8 @@ from .premium import (
     nonTimelyFilingsDF,
     precisionAlphaPriceDynamics,
     precisionAlphaPriceDynamicsDF,
-    productEventsDF,
     productEvents,
+    productEventsDF,
     researchAndDevelopmentDays,
     researchAndDevelopmentDaysDF,
     sameStoreSales,
@@ -228,87 +143,81 @@ from .premium import (
     tacticalModel1DF,
     tradeShows,
     tradeShowsDF,
+    valuEngineStockResearchReport,
     witchingHours,
     witchingHoursDF,
-    valuEngineStockResearchReport,
     workshops,
     workshopsDF,
 )
 from .rates import RatesPoints
 from .refdata import (
-    symbols,
-    symbolsDF,
-    symbolsList,
-    iexSymbols,
-    iexSymbolsDF,
-    iexSymbolsList,
-    mutualFundSymbols,
-    mutualFundSymbolsDF,
-    mutualFundSymbolsList,
-    otcSymbols,
-    otcSymbolsDF,
-    otcSymbolsList,
-    internationalSymbols,
-    internationalSymbolsDF,
-    internationalSymbolsList,
-    fxSymbols,
-    fxSymbolsDF,
-    fxSymbolsList,
-    optionsSymbols,
-    optionsSymbolsDF,
-    optionsSymbolsList,
+    calendar,
+    calendarDF,
+    corporateActions,
+    corporateActionsDF,
     cryptoSymbols,
     cryptoSymbolsDF,
     cryptoSymbolsList,
-    isinLookup,
-    isinLookupDF,
-    corporateActions,
-    corporateActionsDF,
-    refDividends,
-    refDividendsDF,
-    nextDayExtDate,
-    nextDayExtDateDF,
     directory,
     directoryDF,
-    calendar,
-    calendarDF,
-    holidays,
-    holidaysDF,
     exchanges,
     exchangesDF,
     figi,
     figiDF,
+    fxSymbols,
+    fxSymbolsDF,
+    fxSymbolsList,
+    holidays,
+    holidaysDF,
+    iexSymbols,
+    iexSymbolsDF,
+    iexSymbolsList,
     internationalExchanges,
     internationalExchangesDF,
-    sectors,
-    sectorsDF,
+    internationalSymbols,
+    internationalSymbolsDF,
+    internationalSymbolsList,
+    isinLookup,
+    isinLookupDF,
+    mutualFundSymbols,
+    mutualFundSymbolsDF,
+    mutualFundSymbolsList,
+    nextDayExtDate,
+    nextDayExtDateDF,
+    optionsSymbols,
+    optionsSymbolsDF,
+    optionsSymbolsList,
+    otcSymbols,
+    otcSymbolsDF,
+    otcSymbolsList,
+    refDividends,
+    refDividendsDF,
     search,
     searchDF,
+    sectors,
+    sectorsDF,
+    symbols,
+    symbolsDF,
+    symbolsList,
     tags,
     tagsDF,
 )
-from .rules import (
-    schema,
-    create,
-    lookup,
-    pause,
-    resume,
-    delete,
-    rule as ruleInfo,
-    rules,
-    output as ruleOutput,
-)
+from .rules import create, delete, lookup
+from .rules import output as ruleOutput
+from .rules import pause, resume
+from .rules import rule as ruleInfo
+from .rules import rules, schema
 from .stats import (
-    stats,
-    statsDF,
+    daily,
+    dailyDF,
     recent,
     recentDF,
     records,
     recordsDF,
+    stats,
+    statsDF,
     summary,
     summaryDF,
-    daily,
-    dailyDF,
 )
 from .stocks import (
     advancedStats,
@@ -319,30 +228,30 @@ from .stocks import (
     balanceSheetDF,
     batch,
     batchDF,
-    bulkBatch,
-    bulkBatchDF,
-    book,
-    bookDF,
     bonusIssue,
     bonusIssueDF,
+    book,
+    bookDF,
+    bulkBatch,
+    bulkBatchDF,
     bulkMinuteBars,
     bulkMinuteBarsDF,
     cashFlow,
     cashFlowDF,
     chart,
     chartDF,
-    company,
-    companyDF,
     collections,
     collectionsDF,
+    company,
+    companyDF,
     delayedQuote,
     delayedQuoteDF,
     distribution,
     distributionDF,
     dividends,
-    dividendsDF,
     dividendsBasic,
     dividendsBasicDF,
+    dividendsDF,
     earnings,
     earningsDF,
     earningsToday,
@@ -351,10 +260,52 @@ from .stocks import (
     estimatesDF,
     financials,
     financialsDF,
-    fundOwnership,
-    fundOwnershipDF,
     fundamentals,
     fundamentalsDF,
+    fundOwnership,
+    fundOwnershipDF,
+    iexAuction,
+    iexAuctionAsync,
+    iexAuctionDF,
+    iexBook,
+    iexBookAsync,
+    iexBookDF,
+    iexDeep,
+    iexDeepAsync,
+    iexDeepDF,
+    iexHist,
+    iexHistAsync,
+    iexHistDF,
+    iexLast,
+    iexLastAsync,
+    iexLastDF,
+    iexOfficialPrice,
+    iexOfficialPriceAsync,
+    iexOfficialPriceDF,
+    iexOpHaltStatus,
+    iexOpHaltStatusAsync,
+    iexOpHaltStatusDF,
+    iexSecurityEvent,
+    iexSecurityEventAsync,
+    iexSecurityEventDF,
+    iexSsrStatus,
+    iexSsrStatusAsync,
+    iexSsrStatusDF,
+    iexSystemEvent,
+    iexSystemEventAsync,
+    iexSystemEventDF,
+    iexTops,
+    iexTopsAsync,
+    iexTopsDF,
+    iexTradeBreak,
+    iexTradeBreakAsync,
+    iexTradeBreakDF,
+    iexTrades,
+    iexTradesAsync,
+    iexTradesDF,
+    iexTradingStatus,
+    iexTradingStatusAsync,
+    iexTradingStatusDF,
     incomeStatement,
     incomeStatementDF,
     insiderRoster,
@@ -371,10 +322,6 @@ from .stocks import (
     ipoTodayDF,
     ipoUpcoming,
     ipoUpcomingDF,
-    marketShortInterest,
-    marketShortInterestDF,
-    marketVolume,
-    marketVolumeDF,
     keyStats,
     keyStatsDF,
     largestTrades,
@@ -382,20 +329,28 @@ from .stocks import (
     list,
     listDF,
     logo,
-    logoPNG,
     logoNotebook,
-    news,
-    newsDF,
+    logoPNG,
     marketNews,
     marketNewsDF,
-    ohlc,
-    ohlcDF,
     marketOhlc,
     marketOhlcDF,
-    peers,
-    peersDF,
+    marketPrevious,
+    marketPreviousDF,
+    marketShortInterest,
+    marketShortInterestDF,
+    marketVolume,
+    marketVolumeDF,
     marketYesterday,
     marketYesterdayDF,
+    news,
+    newsDF,
+    ohlc,
+    ohlcDF,
+    peers,
+    peersDF,
+    previous,
+    previousDF,
     price,
     priceDF,
     priceTarget,
@@ -418,128 +373,107 @@ from .stocks import (
     securitySwapDF,
     shortInterest,
     shortInterestDF,
-    splits,
-    splitsDF,
     spinoff,
     spinoffDF,
+    splits,
+    splitsDF,
     spread,
     spreadDF,
     stockSplits,
     stockSplitsDF,
-    tenQ,
-    tenK,
-    threshold,
-    thresholdDF,
     technicals,
     technicalsDF,
-    timeSeriesInventory,
+    tenK,
+    tenQ,
+    threshold,
+    thresholdDF,
     timeSeries,
-    timeSeriesInventoryDF,
     timeSeriesDF,
-    upcomingEvents,
-    upcomingEventsDF,
-    upcomingEarnings,
-    upcomingEarningsDF,
+    timeSeriesInventory,
+    timeSeriesInventoryDF,
     upcomingDividends,
     upcomingDividendsDF,
-    upcomingSplits,
-    upcomingSplitsDF,
+    upcomingEarnings,
+    upcomingEarningsDF,
+    upcomingEvents,
+    upcomingEventsDF,
     upcomingIPOs,
     upcomingIPOsDF,
+    upcomingSplits,
+    upcomingSplitsDF,
     volumeByVenue,
     volumeByVenueDF,
     yesterday,
     yesterdayDF,
 )
-from .options import optionExpirations, options, optionsDF
+from .streaming.cryptocurrency import (
+    cryptoBookSSE,
+    cryptoBookSSEAsync,
+    cryptoEventsSSE,
+    cryptoEventsSSEAsync,
+    cryptoQuotesSSE,
+    cryptoQuotesSSEAsync,
+)
+from .streaming.fx import (
+    forex1MinuteSSE,
+    forex1MinuteSSEAsync,
+    forex1SecondSSE,
+    forex1SecondSSEAsync,
+    forex5SecondSSE,
+    forex5SecondSSEAsync,
+    fxSSE,
+    fxSSEAsync,
+)
+from .streaming.news import newsSSE, newsSSEAsync
+from .streaming.sentiment import sentimentSSE, sentimentSSEAsync
+from .streaming.sse import (
+    iexDeepSSE,
+    iexDeepSSEAsync,
+    iexLastSSE,
+    iexLastSSEAsync,
+    iexTopsSSE,
+    iexTopsSSEAsync,
+    iexTradesSSE,
+    iexTradesSSEAsync,
+)
+from .streaming.stock import (
+    stocksUS1MinuteSSE,
+    stocksUSNoUTP1MinuteSSE,
+    stocksUS1MinuteSSEAsync,
+    stocksUSNoUTP1MinuteSSEAsync,
+    stocksUS1SecondSSE,
+    stocksUSNoUTP1SecondSSE,
+    stocksUS1SecondSSEAsync,
+    stocksUSNoUTP1SecondSSEAsync,
+    stocksUS5SecondSSE,
+    stocksUSNoUTP5SecondSSE,
+    stocksUS5SecondSSEAsync,
+    stocksUSNoUTP5SecondSSEAsync,
+    stocksUSNoUTPSSE,
+    stocksUSNoUTPSSEAsync,
+    stocksUSSSE,
+    stocksUSSSEAsync,
+)
 
 try:
-    from .studies import (
-        peerCorrelation,
-        peerCorrelationPlot,
-        returns,
-        dailyReturns,
-        # Cycle
-        ht_dcperiod,
-        ht_dcphase,
-        ht_phasor,
-        ht_sine,
-        ht_trendmode,
-        # Math
+    from .studies import (  # Cycle; Math; Momentum; Overlap; Pattern; Price; Statistic; Volatility; Volume
         acos,
-        asin,
-        atan,
-        ceil,
-        cos,
-        cosh,
-        exp,
-        floor,
-        ln,
-        log10,
-        sin,
-        sinh,
-        sqrt,
-        tan,
-        tanh,
+        ad,
         add,
-        div,
-        max,
-        maxindex,
-        min,
-        minindex,
-        minmax,
-        minmaxindex,
-        mult,
-        sub,
-        sum,
-        # Momentum
+        adosc,
         adx,
         adxr,
         apo,
         aroon,
         aroonosc,
+        asin,
+        atan,
+        atr,
+        avgprice,
+        beta,
+        bollinger,
         bop,
         cci,
-        cmo,
-        dx,
-        macd,
-        macdext,
-        mfi,
-        minus_di,
-        minus_dm,
-        mom,
-        plus_di,
-        plus_dm,
-        ppo,
-        roc,
-        rocp,
-        rocr,
-        rocr100,
-        rsi,
-        stoch,
-        stochf,
-        stochrsi,
-        trix,
-        ultosc,
-        willr,
-        # Overlap
-        bollinger,
-        dema,
-        ema,
-        ht_trendline,
-        kama,
-        mama,
-        mavp,
-        midpoint,
-        midpice,
-        sar,
-        sarext,
-        sma,
-        t3,
-        tema,
-        trima,
-        wma,
-        # Pattern
         cdl2crows,
         cdl3blackcrows,
         cdl3inside,
@@ -600,29 +534,88 @@ try:
         cdltristar,
         cdlunique3river,
         cdlxsidegap3methods,
-        # Price
-        avgprice,
-        medprice,
-        typprice,
-        wclprice,
-        # Statistic
-        beta,
+        ceil,
+        cmo,
         correl,
+        cos,
+        cosh,
+        dailyReturns,
+        dema,
+        div,
+        dx,
+        ema,
+        exp,
+        floor,
+        ht_dcperiod,
+        ht_dcphase,
+        ht_phasor,
+        ht_sine,
+        ht_trendline,
+        ht_trendmode,
+        kama,
         linearreg,
         linearreg_angle,
         linearreg_intercept,
         linearreg_slope,
-        stddev,
-        tsf,
-        var,
-        # Volatility
-        atr,
+        ln,
+        log10,
+        macd,
+        macdext,
+        mama,
+        mavp,
+        max,
+        maxindex,
+        medprice,
+        mfi,
+        midpice,
+        midpoint,
+        min,
+        minindex,
+        minmax,
+        minmaxindex,
+        minus_di,
+        minus_dm,
+        mom,
+        mult,
         natr,
-        trange,
-        # Volume
-        ad,
-        adosc,
         obv,
+        peerCorrelation,
+        peerCorrelationPlot,
+        plus_di,
+        plus_dm,
+        ppo,
+        returns,
+        roc,
+        rocp,
+        rocr,
+        rocr100,
+        rsi,
+        sar,
+        sarext,
+        sin,
+        sinh,
+        sma,
+        sqrt,
+        stddev,
+        stoch,
+        stochf,
+        stochrsi,
+        sub,
+        sum,
+        t3,
+        tan,
+        tanh,
+        tema,
+        trange,
+        trima,
+        trix,
+        tsf,
+        typprice,
+        ultosc,
+        var,
+        wclprice,
+        willr,
+        wma,
     )
 
 except ImportError:
@@ -919,6 +912,48 @@ _INCLUDE_FUNCTIONS = [
     ("fundOwnershipDF", fundOwnershipDF),
     ("fundamentals", fundamentals),
     ("fundamentalsDF", fundamentalsDF),
+    ("iexAuction", iexAuction),
+    ("iexAuctionAsync", iexAuctionAsync),
+    ("iexAuctionDF", iexAuctionDF),
+    ("iexBook", iexBook),
+    ("iexBookAsync", iexBookAsync),
+    ("iexBookDF", iexBookDF),
+    ("iexDeep", iexDeep),
+    ("iexDeepAsync", iexDeepAsync),
+    ("iexDeepDF", iexDeepDF),
+    ("iexHist", iexHist),
+    ("iexHistAsync", iexHistAsync),
+    ("iexHistDF", iexHistDF),
+    ("iexLast", iexLast),
+    ("iexLastAsync", iexLastAsync),
+    ("iexLastDF", iexLastDF),
+    ("iexOfficialPrice", iexOfficialPrice),
+    ("iexOfficialPriceAsync", iexOfficialPriceAsync),
+    ("iexOfficialPriceDF", iexOfficialPriceDF),
+    ("iexOpHaltStatus", iexOpHaltStatus),
+    ("iexOpHaltStatusAsync", iexOpHaltStatusAsync),
+    ("iexOpHaltStatusDF", iexOpHaltStatusDF),
+    ("iexSecurityEvent", iexSecurityEvent),
+    ("iexSecurityEventAsync", iexSecurityEventAsync),
+    ("iexSecurityEventDF", iexSecurityEventDF),
+    ("iexSsrStatus", iexSsrStatus),
+    ("iexSsrStatusAsync", iexSsrStatusAsync),
+    ("iexSsrStatusDF", iexSsrStatusDF),
+    ("iexSystemEvent", iexSystemEvent),
+    ("iexSystemEventAsync", iexSystemEventAsync),
+    ("iexSystemEventDF", iexSystemEventDF),
+    ("iexTops", iexTops),
+    ("iexTopsAsync", iexTopsAsync),
+    ("iexTopsDF", iexTopsDF),
+    ("iexTradeBreak", iexTradeBreak),
+    ("iexTradeBreakAsync", iexTradeBreakAsync),
+    ("iexTradeBreakDF", iexTradeBreakDF),
+    ("iexTrades", iexTrades),
+    ("iexTradesAsync", iexTradesAsync),
+    ("iexTradesDF", iexTradesDF),
+    ("iexTradingStatus", iexTradingStatus),
+    ("iexTradingStatusAsync", iexTradingStatusAsync),
+    ("iexTradingStatusDF", iexTradingStatusDF),
     ("incomeStatement", incomeStatement),
     ("incomeStatementDF", incomeStatementDF),
     ("insiderRoster", insiderRoster),
@@ -967,8 +1002,12 @@ _INCLUDE_FUNCTIONS = [
     ("optionsDF", optionsDF),
     ("peers", peers),
     ("peersDF", peersDF),
+    ("previous", previous),
+    ("previousDF", previousDF),
     ("yesterday", yesterday),
     ("yesterdayDF", yesterdayDF),
+    ("marketPrevious", marketPrevious),
+    ("marketPreviousDF", marketPreviousDF),
     ("marketYesterday", marketYesterday),
     ("marketYesterdayDF", marketYesterdayDF),
     ("price", price),
@@ -1018,68 +1057,31 @@ _INCLUDE_FUNCTIONS = [
     ("volumeByVenue", volumeByVenue),
     ("volumeByVenueDF", volumeByVenueDF),
     # SSE Streaming
-    ("topsSSE", topsSSE),
-    ("topsSSEAsync", topsSSEAsync),
-    ("lastSSE", lastSSE),
-    ("lastSSEAsync", lastSSEAsync),
-    ("deepSSE", deepSSE),
-    ("deepSSEAsync", deepSSEAsync),
-    ("tradesSSE", tradesSSE),
-    ("tradesSSEAsync", tradesSSEAsync),
+    ("topsSSE", iexTopsSSE),
+    ("topsSSEAsync", iexTopsSSEAsync),
+    ("lastSSE", iexLastSSE),
+    ("lastSSEAsync", iexLastSSEAsync),
+    ("deepSSE", iexDeepSSE),
+    ("deepSSEAsync", iexDeepSSEAsync),
+    ("tradesSSE", iexTradesSSE),
+    ("tradesSSEAsync", iexTradesSSEAsync),
     # Stock SSE
     ("stocksUSNoUTPSSE", stocksUSNoUTPSSE),
     ("stocksUSNoUTPSSEAsync", stocksUSNoUTPSSEAsync),
     ("stocksUSSSE", stocksUSSSE),
     ("stocksUSSSEAsync", stocksUSSSEAsync),
     ("stocksUS1SecondSSE", stocksUS1SecondSSE),
+    ("stocksUSNoUTP1SecondSSE", stocksUSNoUTP1SecondSSE),
     ("stocksUS1SecondSSEAsync", stocksUS1SecondSSEAsync),
+    ("stocksUSNoUTP1SecondSSEAsync", stocksUSNoUTP1SecondSSEAsync),
     ("stocksUS5SecondSSE", stocksUS5SecondSSE),
+    ("stocksUSNoUTP5SecondSSE", stocksUSNoUTP5SecondSSE),
     ("stocksUS5SecondSSEAsync", stocksUS5SecondSSEAsync),
+    ("stocksUSNoUTP5SecondSSEAsync", stocksUSNoUTP5SecondSSEAsync),
     ("stocksUS1MinuteSSE", stocksUS1MinuteSSE),
+    ("stocksUSNoUTP1MinuteSSE", stocksUSNoUTP1MinuteSSE),
     ("stocksUS1MinuteSSEAsync", stocksUS1MinuteSSEAsync),
-    # TOPS
-    ("tops", tops),
-    ("topsAsync", topsAsync),
-    ("topsDF", topsDF),
-    ("last", last),
-    ("lastAsync", lastAsync),
-    ("lastDF", lastDF),
-    ("deep", deep),
-    ("deepAsync", deepAsync),
-    ("deepDF", deepDF),
-    ("hist", hist),
-    ("histAsync", histAsync),
-    ("histDF", histDF),
-    ("auction", auction),
-    ("auctionAsync", auctionAsync),
-    ("auctionDF", auctionDF),
-    ("bookDeep", deepBook),
-    ("bookDeepAsync", deepBookAsync),
-    ("bookDeepDF", deepBookDF),
-    ("officialPrice", officialPrice),
-    ("officialPriceAsync", officialPriceAsync),
-    ("officialPriceDF", officialPriceDF),
-    ("opHaltStatus", opHaltStatus),
-    ("opHaltStatusAsync", opHaltStatusAsync),
-    ("opHaltStatusDF", opHaltStatusDF),
-    ("securityEvent", securityEvent),
-    ("securityEventAsync", securityEventAsync),
-    ("securityEventDF", securityEventDF),
-    ("ssrStatus", ssrStatus),
-    ("ssrStatusAsync", ssrStatusAsync),
-    ("ssrStatusDF", ssrStatusDF),
-    ("systemEvent", systemEvent),
-    ("systemEventAsync", systemEventAsync),
-    ("systemEventDF", systemEventDF),
-    ("trades", trades),
-    ("tradesAsync", tradesAsync),
-    ("tradesDF", tradesDF),
-    ("tradeBreak", tradeBreak),
-    ("tradeBreakAsync", tradeBreakAsync),
-    ("tradeBreakDF", tradeBreakDF),
-    ("tradingStatus", tradingStatus),
-    ("tradingStatusAsync", tradingStatusAsync),
-    ("tradingStatusDF", tradingStatusDF),
+    ("stocksUSNoUTP1MinuteSSEAsync", stocksUSNoUTP1MinuteSSEAsync),
     # Account
     ("messageBudget", messageBudget),
     ("metadata", metadata),
@@ -1087,8 +1089,6 @@ _INCLUDE_FUNCTIONS = [
     ("usage", usage),
     ("usageDF", usageDF),
     # Alternative
-    ("crypto", crypto),
-    ("cryptoDF", cryptoDF),
     ("sentiment", sentiment),
     ("sentimentDF", sentimentDF),
     ("ceoCompensation", ceoCompensation),
