@@ -1,7 +1,14 @@
-# -*- coding: utf-8 -*-
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 from functools import wraps
+
+from ...common import _UTC, _expire
 from ...stocks import timeSeries, timeSeriesDF
-from ...common import _expire, _UTC
 
 
 @_expire(hour=3, tz=_UTC)
@@ -346,7 +353,7 @@ def esgUSPTOPatentGrants(symbol="", **kwargs):
     Args:
         symbol (str): symbol to use
     """
-    kwargs["subkey"] = "10"
+    kwargs["subkey"] = "11"
     return _base(id="PREMIUM_EXTRACT_ALPHA_ESG", symbol=symbol, **kwargs)
 
 
@@ -361,7 +368,7 @@ def esgUSPTOPatentGrantsDF(symbol="", **kwargs):
     Args:
         symbol (str): symbol to use
     """
-    kwargs["subkey"] = "10"
+    kwargs["subkey"] = "11"
     return _baseDF(id="PREMIUM_EXTRACT_ALPHA_ESG", symbol=symbol, **kwargs)
 
 
