@@ -1,16 +1,25 @@
-# -*- coding: utf-8 -*-
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 from functools import wraps
+
 from ...common import (
-    _getJson,
     PyEXception,
-    _toDatetime,
-    _strOrDate,
+    _get,
     _raiseIfNotStr,
+    _strOrDate,
+    _toDatetime,
     json_normalize,
 )
 
 
-def socialSentiment(symbol, type="daily", date="", token="", version="", filter=""):
+def socialSentiment(
+    symbol, type="daily", date="", token="", version="stable", filter="", format="json"
+):
     """This endpoint provides social sentiment data from StockTwits. Data can be viewed as a daily value, or by minute for a given date.
 
     https://iexcloud.io/docs/api/#social-sentiment
@@ -22,6 +31,7 @@ def socialSentiment(symbol, type="daily", date="", token="", version="", filter=
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -35,7 +45,7 @@ def socialSentiment(symbol, type="daily", date="", token="", version="", filter=
     if date:
         date = _strOrDate(date)
         base_url += "/{}".format(date)
-    return _getJson(base_url, token, version, filter)
+    return _get(base_url, token, version, filter)
 
 
 @wraps(socialSentiment)
