@@ -1,48 +1,49 @@
-from .symbols import (
-    symbols,
-    iexSymbols,
-    mutualFundSymbols,
-    otcSymbols,
-    internationalSymbols,
-    fxSymbols,
-    optionsSymbols,
-    cryptoSymbols,
-    symbolsDF,
-    iexSymbolsDF,
-    mutualFundSymbolsDF,
-    otcSymbolsDF,
-    internationalSymbolsDF,
-    fxSymbolsDF,
-    optionsSymbolsDF,
-    cryptoSymbolsDF,
-    symbolsList,
-    iexSymbolsList,
-    mutualFundSymbolsList,
-    otcSymbolsList,
-    internationalSymbolsList,
-    fxSymbolsList,
-    optionsSymbolsList,
-    cryptoSymbolsList,
-    isinLookup,
-    isinLookupDF,
-)
-from .refdata import (
-    corporateActions,
-    corporateActionsDF,
-    dividends as refDividends,
-    dividendsDF as refDividendsDF,
-    nextDayExtDate,
-    nextDayExtDateDF,
-    directory,
-    directoryDF,
-)
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 from .calendar import calendar, calendarDF, holidays, holidaysDF
-from .figi import figi, figiDF
 from .exchanges import (
     exchanges,
     exchangesDF,
     internationalExchanges,
     internationalExchangesDF,
 )
-from .sectors import sectors, sectorsDF, tags, tagsDF
+from .figi import figi, figiDF
+from .refdata import corporateActions, corporateActionsDF, directory, directoryDF
+from .refdata import dividends as refDividends
+from .refdata import dividendsDF as refDividendsDF
+from .refdata import nextDayExtDate, nextDayExtDateDF
 from .search import search, searchDF
+from .sectors import sectors, sectorsDF, tags, tagsDF
+from .symbols import (
+    cryptoSymbols,
+    cryptoSymbolsDF,
+    cryptoSymbolsList,
+    fxSymbols,
+    fxSymbolsDF,
+    fxSymbolsList,
+    iexSymbols,
+    iexSymbolsDF,
+    iexSymbolsList,
+    internationalSymbols,
+    internationalSymbolsDF,
+    internationalSymbolsList,
+    isinLookup,
+    isinLookupDF,
+    mutualFundSymbols,
+    mutualFundSymbolsDF,
+    mutualFundSymbolsList,
+    optionsSymbols,
+    optionsSymbolsDF,
+    optionsSymbolsList,
+    otcSymbols,
+    otcSymbolsDF,
+    otcSymbolsList,
+    symbols,
+    symbolsDF,
+    symbolsList,
+)
