@@ -1,3 +1,10 @@
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 from .batch import (
     batch,
     batchDF,
@@ -28,13 +35,10 @@ from .corporateActions import (
     splits,
     splitsDF,
 )
+from .fundamentals import balanceSheet, balanceSheetDF, cashFlow, cashFlowDF
+from .fundamentals import dividends as dividendsBasic
+from .fundamentals import dividendsDF as dividendsBasicDF
 from .fundamentals import (
-    balanceSheet,
-    balanceSheetDF,
-    cashFlow,
-    cashFlowDF,
-    dividends as dividendsBasic,
-    dividendsDF as dividendsBasicDF,
     earnings,
     earningsDF,
     financials,
@@ -46,6 +50,50 @@ from .fundamentals import (
     stockSplits,
     stockSplitsDF,
 )
+from .iex import (
+    iexAuction,
+    iexAuctionAsync,
+    iexAuctionDF,
+    iexBook,
+    iexBookAsync,
+    iexBookDF,
+    iexDeep,
+    iexDeepAsync,
+    iexDeepDF,
+    iexHist,
+    iexHistAsync,
+    iexHistDF,
+    iexLast,
+    iexLastAsync,
+    iexLastDF,
+    iexOfficialPrice,
+    iexOfficialPriceAsync,
+    iexOfficialPriceDF,
+    iexOpHaltStatus,
+    iexOpHaltStatusAsync,
+    iexOpHaltStatusDF,
+    iexSecurityEvent,
+    iexSecurityEventAsync,
+    iexSecurityEventDF,
+    iexSsrStatus,
+    iexSsrStatusAsync,
+    iexSsrStatusDF,
+    iexSystemEvent,
+    iexSystemEventAsync,
+    iexSystemEventDF,
+    iexTops,
+    iexTopsAsync,
+    iexTopsDF,
+    iexTradeBreak,
+    iexTradeBreakAsync,
+    iexTradeBreakDF,
+    iexTrades,
+    iexTradesAsync,
+    iexTradesDF,
+    iexTradingStatus,
+    iexTradingStatusAsync,
+    iexTradingStatusDF,
+)
 from .marketInfo import (
     collections,
     collectionsDF,
@@ -57,28 +105,30 @@ from .marketInfo import (
     ipoUpcomingDF,
     list,
     listDF,
-    marketVolume,
-    marketVolumeDF,
     marketOhlc,
     marketOhlcDF,
+    marketPrevious,
+    marketPreviousDF,
+    marketShortInterest,
+    marketShortInterestDF,
+    marketVolume,
+    marketVolumeDF,
     marketYesterday,
     marketYesterdayDF,
     sectorPerformance,
     sectorPerformanceDF,
-    marketShortInterest,
-    marketShortInterestDF,
-    upcomingEvents,
-    upcomingEventsDF,
-    upcomingEarnings,
-    upcomingEarningsDF,
     upcomingDividends,
     upcomingDividendsDF,
-    upcomingSplits,
-    upcomingSplitsDF,
+    upcomingEarnings,
+    upcomingEarningsDF,
+    upcomingEvents,
+    upcomingEventsDF,
     upcomingIPOs,
     upcomingIPOsDF,
+    upcomingSplits,
+    upcomingSplitsDF,
 )
-from .news import news, newsDF, marketNews, marketNewsDF
+from .news import marketNews, marketNewsDF, news, newsDF
 from .prices import (
     book,
     bookDF,
@@ -92,8 +142,8 @@ from .prices import (
     largestTradesDF,
     ohlc,
     ohlcDF,
-    yesterday,
-    yesterdayDF,
+    previous,
+    previousDF,
     price,
     priceDF,
     quote,
@@ -102,6 +152,8 @@ from .prices import (
     spreadDF,
     volumeByVenue,
     volumeByVenueDF,
+    yesterday,
+    yesterdayDF,
 )
 from .profiles import (
     company,
@@ -113,8 +165,8 @@ from .profiles import (
     insiderTransactions,
     insiderTransactionsDF,
     logo,
-    logoPNG,
     logoNotebook,
+    logoPNG,
     peers,
     peersDF,
     relevant,
@@ -138,14 +190,12 @@ from .research import (
     technicals,
     technicalsDF,
 )
-
-from .stocks import threshold, thresholdDF, shortInterest, shortInterestDF
-
+from .stocks import shortInterest, shortInterestDF, threshold, thresholdDF
 from .timeseries import (
-    timeSeriesInventory,
-    timeSeries,
-    timeSeriesInventoryDF,
-    timeSeriesDF,
-    tenQ,
     tenK,
+    tenQ,
+    timeSeries,
+    timeSeriesDF,
+    timeSeriesInventory,
+    timeSeriesInventoryDF,
 )
