@@ -1,12 +1,26 @@
-# -*- coding: utf-8 -*-
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 from functools import wraps
+
 import pandas as pd
-from ..common import _raiseIfNotStr, _quoteSymbols, _timeseriesWrapper
+
+from ..common import _quoteSymbols, _raiseIfNotStr, _timeseriesWrapper
 from .timeseries import timeSeries
 
 
 def bonusIssue(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
     """Bonus Issue Obtain up-to-date and detailed information on all new announcements, as well as 12+ years of historical records.
 
@@ -20,6 +34,7 @@ def bonusIssue(
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
         Supports all kwargs from `pyEX.stocks.timeseries.timeSeries`
 
@@ -36,21 +51,24 @@ def bonusIssue(
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(bonusIssue)
-def bonusIssueDF(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
-):
-    return pd.DataFrame(
-        bonusIssue(symbol, refid, token, version, filter, **timeseries_kwargs)
-    )
+def bonusIssueDF(*args, **kwargs):
+    return pd.DataFrame(bonusIssue(*args, **kwargs))
 
 
 def distribution(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
     """Distribution Obtain up-to-date and detailed information on all new announcements, as well as 12+ years of historical records.
 
@@ -64,6 +82,7 @@ def distribution(
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
         Supports all kwargs from `pyEX.stocks.timeseries.timeSeries`
 
@@ -80,21 +99,24 @@ def distribution(
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(distribution)
-def distributionDF(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
-):
-    return pd.DataFrame(
-        distribution(symbol, refid, token, version, filter, **timeseries_kwargs)
-    )
+def distributionDF(*args, **kwargs):
+    return pd.DataFrame(distribution(*args, **kwargs))
 
 
 def dividends(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
     """Obtain up-to-date and detailed information on all new dividend announcements, as well as 12+ years of historical dividend records. This endpoint covers over 39,000 US equities, mutual funds, ADRs, and ETFs.
     You’ll be provided with:
@@ -114,6 +136,7 @@ def dividends(
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
         Supports all kwargs from `pyEX.stocks.timeseries.timeSeries`
 
@@ -130,21 +153,24 @@ def dividends(
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(dividends)
-def dividendsDF(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
-):
-    return pd.DataFrame(
-        dividends(symbol, refid, token, version, filter, **timeseries_kwargs)
-    )
+def dividendsDF(*args, **kwargs):
+    return pd.DataFrame(dividends(*args, **kwargs))
 
 
 def returnOfCapital(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
     """Return of capital up-to-date and detailed information on all new announcements, as well as 12+ years of historical records.
 
@@ -158,6 +184,7 @@ def returnOfCapital(
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -172,21 +199,24 @@ def returnOfCapital(
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(returnOfCapital)
-def returnOfCapitalDF(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
-):
-    return pd.DataFrame(
-        returnOfCapital(symbol, refid, token, version, filter, **timeseries_kwargs)
-    )
+def returnOfCapitalDF(*args, **kwargs):
+    return pd.DataFrame(returnOfCapital(*args, **kwargs))
 
 
 def rightsIssue(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
     """Rights issue up-to-date and detailed information on all new announcements, as well as 12+ years of historical records.
 
@@ -200,6 +230,7 @@ def rightsIssue(
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
         Supports all kwargs from `pyEX.stocks.timeseries.timeSeries`
 
@@ -216,21 +247,24 @@ def rightsIssue(
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(rightsIssue)
-def rightsIssueDF(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
-):
-    return pd.DataFrame(
-        rightsIssue(symbol, refid, token, version, filter, **timeseries_kwargs)
-    )
+def rightsIssueDF(*args, **kwargs):
+    return pd.DataFrame(rightsIssue(*args, **kwargs))
 
 
 def rightToPurchase(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
     """Right to purchase up-to-date and detailed information on all new announcements, as well as 12+ years of historical records.
 
@@ -244,6 +278,7 @@ def rightToPurchase(
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
         Supports all kwargs from `pyEX.stocks.timeseries.timeSeries`
 
@@ -260,21 +295,24 @@ def rightToPurchase(
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(rightToPurchase)
-def rightToPurchaseDF(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
-):
-    return pd.DataFrame(
-        rightToPurchase(symbol, refid, token, version, filter, **timeseries_kwargs)
-    )
+def rightToPurchaseDF(*args, **kwargs):
+    return pd.DataFrame(rightToPurchase(*args, **kwargs))
 
 
 def securityReclassification(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
     """Security reclassification up-to-date and detailed information on all new announcements, as well as 12+ years of historical records.
 
@@ -288,6 +326,7 @@ def securityReclassification(
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
         Supports all kwargs from `pyEX.stocks.timeseries.timeSeries`
 
@@ -304,23 +343,24 @@ def securityReclassification(
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(securityReclassification)
-def securityReclassificationDF(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
-):
-    return pd.DataFrame(
-        securityReclassification(
-            symbol, refid, token, version, filter, **timeseries_kwargs
-        )
-    )
+def securityReclassificationDF(*args, **kwargs):
+    return pd.DataFrame(securityReclassification(*args, **kwargs))
 
 
 def securitySwap(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
     """Security Swap up-to-date and detailed information on all new announcements, as well as 12+ years of historical records.
 
@@ -334,6 +374,7 @@ def securitySwap(
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
         Supports all kwargs from `pyEX.stocks.timeseries.timeSeries`
 
@@ -350,20 +391,25 @@ def securitySwap(
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(securitySwap)
-def securitySwapDF(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+def securitySwapDF(*args, **kwargs):
+    return pd.DataFrame(securitySwap(*args, **kwargs))
+
+
+def spinoff(
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
-    return pd.DataFrame(
-        securitySwap(symbol, refid, token, version, filter, **timeseries_kwargs)
-    )
-
-
-def spinoff(symbol="", refid="", token="", version="", filter="", **timeseries_kwargs):
     """Security spinoff up-to-date and detailed information on all new announcements, as well as 12+ years of historical records.
 
     Updated at 5am, 10am, 8pm UTC daily
@@ -376,6 +422,7 @@ def spinoff(symbol="", refid="", token="", version="", filter="", **timeseries_k
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
         Supports all kwargs from `pyEX.stocks.timeseries.timeSeries`
 
@@ -392,20 +439,25 @@ def spinoff(symbol="", refid="", token="", version="", filter="", **timeseries_k
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(spinoff)
-def spinoffDF(
-    symbol="", refid="", token="", version="", filter="", **timeseries_kwargs
+def spinoffDF(*args, **kwargs):
+    return pd.DataFrame(spinoff(*args, **kwargs))
+
+
+def splits(
+    symbol="",
+    refid="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+    **timeseries_kwargs
 ):
-    return pd.DataFrame(
-        spinoff(symbol, refid, token, version, filter, **timeseries_kwargs)
-    )
-
-
-def splits(symbol="", refid="", token="", version="", filter="", **timeseries_kwargs):
     """Security splits up-to-date and detailed information on all new announcements, as well as 12+ years of historical records.
 
     Updated at 5am, 10am, 8pm UTC daily
@@ -418,6 +470,7 @@ def splits(symbol="", refid="", token="", version="", filter="", **timeseries_kw
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
         Supports all kwargs from `pyEX.stocks.timeseries.timeSeries`
 
@@ -434,12 +487,11 @@ def splits(symbol="", refid="", token="", version="", filter="", **timeseries_kw
         token=token,
         version=version,
         filter=filter,
+        format=format,
         **timeseries_kwargs
     )
 
 
 @wraps(splits)
-def splitsDF(symbol="", refid="", token="", version="", filter="", **timeseries_kwargs):
-    return pd.DataFrame(
-        splits(symbol, refid, token, version, filter, **timeseries_kwargs)
-    )
+def splitsDF(*args, **kwargs):
+    return pd.DataFrame(splits(*args, **kwargs))
