@@ -1,23 +1,39 @@
-# -*- coding: utf-8 -*-
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 from functools import wraps
-import pandas as pd
+
 import numpy as np
+import pandas as pd
+
 from ..common import (
-    _expire,
     _TIMEFRAME_DIVSPLIT,
-    _getJson,
-    _raiseIfNotStr,
+    _UTC,
     PyEXception,
+    _checkPeriodLast,
+    _expire,
+    _get,
+    _quoteSymbols,
+    _raiseIfNotStr,
     _reindex,
     _toDatetime,
-    _checkPeriodLast,
-    _UTC,
-    _quoteSymbols,
 )
 
 
 @_expire(hour=8, tz=_UTC)
-def balanceSheet(symbol, period="quarter", last=1, token="", version="", filter=""):
+def balanceSheet(
+    symbol,
+    period="quarter",
+    last=1,
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+):
     """Pulls balance sheet data. Available quarterly (4 quarters) and annually (4 years)
 
     https://iexcloud.io/docs/api/#balance-sheet
@@ -31,6 +47,7 @@ def balanceSheet(symbol, period="quarter", last=1, token="", version="", filter=
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -38,24 +55,32 @@ def balanceSheet(symbol, period="quarter", last=1, token="", version="", filter=
     _raiseIfNotStr(symbol)
     symbol = _quoteSymbols(symbol)
     _checkPeriodLast(period, last)
-    return _getJson(
+    return _get(
         "stock/{}/balance-sheet?period={}&last={}".format(symbol, period, last),
-        token,
-        version,
-        filter,
+        token=token,
+        version=version,
+        filter=filter,
+        format=format,
     ).get("balancesheet", [])
 
 
 @wraps(balanceSheet)
-def balanceSheetDF(symbol, period="quarter", last=1, token="", version="", filter=""):
-    df = pd.DataFrame(balanceSheet(symbol, period, last, token, version, filter))
-    _toDatetime(df)
-    _reindex(df, "reportDate")
-    return df
+def balanceSheetDF(*args, **kwargs):
+    return _reindex(
+        _toDatetime(pd.DataFrame(balanceSheet(*args, **kwargs))), "reportDate"
+    )
 
 
 @_expire(hour=8, tz=_UTC)
-def cashFlow(symbol, period="quarter", last=1, token="", version="", filter=""):
+def cashFlow(
+    symbol,
+    period="quarter",
+    last=1,
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+):
     """Pulls cash flow data. Available quarterly (4 quarters) or annually (4 years).
 
     https://iexcloud.io/docs/api/#cash-flow
@@ -69,6 +94,7 @@ def cashFlow(symbol, period="quarter", last=1, token="", version="", filter=""):
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -76,25 +102,34 @@ def cashFlow(symbol, period="quarter", last=1, token="", version="", filter=""):
     _raiseIfNotStr(symbol)
     symbol = _quoteSymbols(symbol)
     _checkPeriodLast(period, last)
-    return _getJson(
+    return _get(
         "stock/{}/cash-flow?period={}&last={}".format(symbol, period, last),
-        token,
-        version,
-        filter,
+        token=token,
+        version=version,
+        filter=filter,
+        format=format,
     ).get("cashflow", [])
 
 
 @wraps(cashFlow)
-def cashFlowDF(symbol, period="quarter", last=1, token="", version="", filter=""):
-    df = pd.DataFrame(cashFlow(symbol, period, last, token, version, filter))
-    _toDatetime(df)
-    _reindex(df, "reportDate")
+def cashFlowDF(*args, **kwargs):
+    df = _reindex(
+        _toDatetime(pd.DataFrame(cashFlow(*args, **kwargs))),
+        "reportDate",
+    )
     df.replace(to_replace=[None], value=np.nan, inplace=True)
     return df
 
 
 @_expire(hour=9, tz=_UTC)
-def dividends(symbol, timeframe="ytd", token="", version="", filter=""):
+def dividends(
+    symbol,
+    timeframe="ytd",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+):
     """Dividend history
 
     https://iexcloud.io/docs/api/#dividends
@@ -102,9 +137,11 @@ def dividends(symbol, timeframe="ytd", token="", version="", filter=""):
 
     Args:
         symbol (str): Ticker to request
+        timeframe (str): timeframe for data
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -113,29 +150,34 @@ def dividends(symbol, timeframe="ytd", token="", version="", filter=""):
     symbol = _quoteSymbols(symbol)
     if timeframe not in _TIMEFRAME_DIVSPLIT:
         raise PyEXception("Range must be in %s" % str(_TIMEFRAME_DIVSPLIT))
-    return _getJson(
-        "stock/" + symbol + "/dividends/" + timeframe, token, version, filter
+    return _get(
+        "stock/" + symbol + "/dividends/" + timeframe,
+        token=token,
+        version=version,
+        filter=filter,
+        format=format,
     )
 
 
 def _dividendsToDF(d):
-    """internal"""
-    df = pd.DataFrame(d)
-    _toDatetime(df)
-    _reindex(df, "exDate")
-    return df
+    return _reindex(_toDatetime(pd.DataFrame(d)), "exDate")
 
 
 @wraps(dividends)
-def dividendsDF(symbol, timeframe="ytd", token="", version="", filter=""):
-    d = dividends(symbol, timeframe, token, version, filter)
-    df = _dividendsToDF(d)
-    return df
+def dividendsDF(*args, **kwargs):
+    return _dividendsToDF(dividends(*args, **kwargs))
 
 
 @_expire(hour=9, tz=_UTC)
 def earnings(
-    symbol, period="quarter", last=1, field="", token="", version="", filter=""
+    symbol,
+    period="quarter",
+    last=1,
+    field="",
+    token="",
+    version="stable",
+    filter="",
+    format="json",
 ):
     """Earnings data for a given company including the actual EPS, consensus, and fiscal period. Earnings are available quarterly (last 4 quarters) and annually (last 4 years).
 
@@ -146,9 +188,11 @@ def earnings(
         symbol (str): Ticker to request
         period (str): Period, either 'annual' or 'quarter'
         last (int): Number of records to fetch, up to 12 for 'quarter' and 4 for 'annual'
+        field (str): Subfield to fetch
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -157,42 +201,40 @@ def earnings(
     symbol = _quoteSymbols(symbol)
     _checkPeriodLast(period, last)
     if not field:
-        return _getJson(
+        return _get(
             "stock/{}/earnings?period={}&last={}".format(symbol, period, last),
-            token,
-            version,
-            filter,
-        )
-    return _getJson(
+            token=token,
+            version=version,
+            filter=filter,
+            format=format,
+        ).get("earnings", [])
+    return _get(
         "stock/{}/earnings/{}/{}?period={}".format(symbol, last, field, period),
-        token,
-        version,
-        filter,
+        token=token,
+        version=version,
+        filter=filter,
+        format=format,
     ).get("earnings", [])
 
 
 def _earningsToDF(e):
     """internal"""
     if e:
-        df = pd.DataFrame(e)
-        _toDatetime(df)
-        _reindex(df, "EPSReportDate")
+        df = _reindex(_toDatetime(pd.DataFrame(e)), "EPSReportDate")
     else:
         df = pd.DataFrame()
     return df
 
 
 @wraps(earnings)
-def earningsDF(
-    symbol, period="quarter", last=1, field="", token="", version="", filter=""
-):
-    e = earnings(symbol, period, last, field, token, version, filter)
-    df = _earningsToDF(e)
-    return df
+def earningsDF(*args, **kwargs):
+    return _earningsToDF(earnings(*args, **kwargs))
 
 
 @_expire(hour=8, tz=_UTC)
-def financials(symbol, period="quarter", token="", version="", filter=""):
+def financials(
+    symbol, period="quarter", token="", version="stable", filter="", format="json"
+):
     """Pulls income statement, balance sheet, and cash flow data from the four most recent reported quarters.
 
     https://iexcloud.io/docs/api/#financials
@@ -204,6 +246,7 @@ def financials(symbol, period="quarter", token="", version="", filter=""):
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -211,31 +254,33 @@ def financials(symbol, period="quarter", token="", version="", filter=""):
     _raiseIfNotStr(symbol)
     symbol = _quoteSymbols(symbol)
     _checkPeriodLast(period, 1)
-    return _getJson(
-        "stock/{}/financials?period={}".format(symbol, period), token, version, filter
+    return _get(
+        "stock/{}/financials?period={}".format(symbol, period),
+        token=token,
+        version=version,
+        filter=filter,
+        format=format,
     ).get("financials", [])
 
 
 def _financialsToDF(f):
     """internal"""
     if f:
-        df = pd.DataFrame(f)
-        _toDatetime(df)
-        _reindex(df, "reportDate")
+        df = _reindex(_toDatetime(pd.DataFrame(f)), "reportDate")
     else:
         df = pd.DataFrame()
     return df
 
 
 @wraps(financials)
-def financialsDF(symbol, period="quarter", token="", version="", filter=""):
-    f = financials(symbol, period, token, version, filter)
-    df = _financialsToDF(f)
-    return df
+def financialsDF(*args, **kwargs):
+    return _financialsToDF(financials(*args, **kwargs))
 
 
 @_expire(hour=8, tz=_UTC)
-def fundamentals(symbol, period="quarter", token="", version="", filter=""):
+def fundamentals(
+    symbol, period="quarter", token="", version="stable", filter="", format="json"
+):
     """Pulls fundamentals data.
 
     https://iexcloud.io/docs/api/#advanced-fundamentals
@@ -247,6 +292,7 @@ def fundamentals(symbol, period="quarter", token="", version="", filter=""):
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -254,31 +300,39 @@ def fundamentals(symbol, period="quarter", token="", version="", filter=""):
     _raiseIfNotStr(symbol)
     symbol = _quoteSymbols(symbol)
     _checkPeriodLast(period, 1)
-    return _getJson(
-        "stock/{}/fundamentals?period={}".format(symbol, period), token, version, filter
+    return _get(
+        "stock/{}/fundamentals?period={}".format(symbol, period),
+        token=token,
+        version=version,
+        filter=filter,
+        format=format,
     ).get("fundamentals", [])
 
 
 def _fundamentalsToDF(f):
     """internal"""
     if f:
-        df = pd.DataFrame(f)
-        _toDatetime(df)
-        _reindex(df, "reportDate")
+        df = _reindex(_toDatetime(pd.DataFrame(f)), "reportDate")
     else:
         df = pd.DataFrame()
     return df
 
 
 @wraps(fundamentals)
-def fundamentalsDF(symbol, period="quarter", token="", version="", filter=""):
-    f = fundamentals(symbol, period, token, version, filter)
-    df = _fundamentalsToDF(f)
-    return df
+def fundamentalsDF(*args, **kwargs):
+    return _fundamentalsToDF(fundamentals(*args, **kwargs))
 
 
 @_expire(hour=8, tz=_UTC)
-def incomeStatement(symbol, period="quarter", last=1, token="", version="", filter=""):
+def incomeStatement(
+    symbol,
+    period="quarter",
+    last=1,
+    token="",
+    version="stable",
+    filter="",
+    format="json",
+):
     """Pulls income statement data. Available quarterly (4 quarters) or annually (4 years).
 
     https://iexcloud.io/docs/api/#income-statement
@@ -291,6 +345,7 @@ def incomeStatement(symbol, period="quarter", last=1, token="", version="", filt
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -298,7 +353,7 @@ def incomeStatement(symbol, period="quarter", last=1, token="", version="", filt
     _raiseIfNotStr(symbol)
     symbol = _quoteSymbols(symbol)
     _checkPeriodLast(period, last)
-    return _getJson(
+    return _get(
         "stock/{}/income?period={}&last={}".format(symbol, period, last),
         token,
         version,
@@ -307,17 +362,16 @@ def incomeStatement(symbol, period="quarter", last=1, token="", version="", filt
 
 
 @wraps(incomeStatement)
-def incomeStatementDF(
-    symbol, period="quarter", last=1, token="", version="", filter=""
-):
-    df = pd.DataFrame(incomeStatement(symbol, period, last, token, version, filter))
-    _toDatetime(df)
-    _reindex(df, "reportDate")
-    return df
+def incomeStatementDF(*args, **kwargs):
+    return _reindex(
+        _toDatetime(pd.DataFrame(incomeStatement(*args, **kwargs))), "reportDate"
+    )
 
 
 @_expire(hour=9, tz=_UTC)
-def stockSplits(symbol, timeframe="ytd", token="", version="", filter=""):
+def stockSplits(
+    symbol, timeframe="ytd", token="", version="stable", filter="", format="json"
+):
     """Stock split history
 
     https://iexcloud.io/docs/api/#splits
@@ -325,9 +379,11 @@ def stockSplits(symbol, timeframe="ytd", token="", version="", filter=""):
 
     Args:
         symbol (str): Ticker to request
+        timeframe (str): timeframe for data
         token (str): Access token
         version (str): API version
         filter (str): filters: https://iexcloud.io/docs/api/#filter-results
+        format (str): return format, defaults to json
 
     Returns:
         dict or DataFrame: result
@@ -336,19 +392,19 @@ def stockSplits(symbol, timeframe="ytd", token="", version="", filter=""):
     symbol = _quoteSymbols(symbol)
     if timeframe not in _TIMEFRAME_DIVSPLIT:
         raise PyEXception("Range must be in %s" % str(_TIMEFRAME_DIVSPLIT))
-    return _getJson("stock/" + symbol + "/splits/" + timeframe, token, version, filter)
+    return _get(
+        "stock/" + symbol + "/splits/" + timeframe,
+        token=token,
+        version=version,
+        filter=filter,
+        format=format,
+    )
 
 
-def _splitsToDF(s):
-    """internal"""
-    df = pd.DataFrame(s)
-    _toDatetime(df)
-    _reindex(df, "exDate")
-    return df
+def _splitsToDF(d):
+    return _reindex(_toDatetime(pd.DataFrame(d)), "exDate")
 
 
 @wraps(stockSplits)
-def stockSplitsDF(symbol, timeframe="ytd", token="", version="", filter=""):
-    s = stockSplits(symbol, timeframe, token, version, filter)
-    df = _splitsToDF(s)
-    return df
+def stockSplitsDF(*args, **kwargs):
+    return _splitsToDF(stockSplits(*args, **kwargs))
