@@ -1,6 +1,12 @@
-# -*- coding: utf-8 -*-
-import talib as t
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 import pandas as pd
+import talib as t
 
 
 def cdl2crows(
@@ -29,7 +35,10 @@ def cdl2crows(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDL2CROWS(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -68,7 +77,10 @@ def cdl3blackcrows(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDL3BLACKCROWS(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -107,7 +119,10 @@ def cdl3inside(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDL3INSIDE(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -146,7 +161,10 @@ def cdl3linestrike(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDL3LINESTRIKE(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -185,7 +203,10 @@ def cdl3outside(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDL3OUTSIDE(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -224,7 +245,10 @@ def cdl3starsinsouth(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDL3STARSINSOUTH(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -263,7 +287,10 @@ def cdl3whitesoldiers(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDL3WHITESOLDIERS(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -302,7 +329,10 @@ def cdlabandonedbaby(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLABANDONEDBABY(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -341,7 +371,10 @@ def cdladvanceblock(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLADVANCEBLOCK(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -380,7 +413,10 @@ def cdlbelthold(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLBELTHOLD(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -419,7 +455,10 @@ def cdlbreakaway(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLBREAKAWAY(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -458,7 +497,10 @@ def cdlclosingmarubozu(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLCLOSINGMARUBOZU(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -497,7 +539,10 @@ def cdlconcealbabyswallow(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLCONCEALBABYSWALL(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -536,7 +581,10 @@ def cdlcounterattack(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLCOUNTERATTACK(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -577,10 +625,10 @@ def cdldarkcloudcover(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLDARKCLOUDCOVER(
-        df[opencol].values,
-        df[highcol].values,
-        df[lowcol].values,
-        df[closecol].values,
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
         penetration,
     )
     return pd.DataFrame(
@@ -620,7 +668,10 @@ def cdldoji(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLDOJI(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -659,7 +710,10 @@ def cdldojistar(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLDOJISTAR(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -698,7 +752,10 @@ def cdldragonflydoji(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLDRAGONFLYDOJI(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -737,7 +794,10 @@ def cdlengulfing(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLENGULFING(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -778,10 +838,10 @@ def cdleveningdojistar(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLEVENINGDOJISTAR(
-        df[opencol].values,
-        df[highcol].values,
-        df[lowcol].values,
-        df[closecol].values,
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
         penetration,
     )
     return pd.DataFrame(
@@ -823,10 +883,10 @@ def cdleveningstar(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLEVENINGSTAR(
-        df[opencol].values,
-        df[highcol].values,
-        df[lowcol].values,
-        df[closecol].values,
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
         penetration,
     )
     return pd.DataFrame(
@@ -866,7 +926,10 @@ def cdlgapsidesidewhite(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLGAPSIDESIDEWHITE(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -905,7 +968,10 @@ def cdlgravestonedoji(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLGRAVESTONEDOJI(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -944,7 +1010,10 @@ def cdlhammer(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLHAMMER(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -983,7 +1052,10 @@ def cdlhangingman(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLHANGINGMAN(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1022,7 +1094,10 @@ def cdlharami(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLHARAMI(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1061,7 +1136,10 @@ def cdlharamicross(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLHARAMICROSS(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1100,7 +1178,10 @@ def cdlhighwave(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLHIGHWAVE(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1139,7 +1220,10 @@ def cdlhikkake(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLHIKKAKE(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1178,7 +1262,10 @@ def cdlhikkakemod(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLHIKKAKEMOD(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1217,7 +1304,10 @@ def cdlhomingpigeon(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLHOMINGPIGEON(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1256,7 +1346,10 @@ def cdlidentical3crows(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLIDENTICAL3CROWS(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1295,7 +1388,10 @@ def cdlinneck(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLINNECK(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1334,7 +1430,10 @@ def cdlinvertedhammer(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLINVERTEDHAMMER(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1373,7 +1472,10 @@ def cdlkicking(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLKICKING(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1412,7 +1514,10 @@ def cdlkickingbylength(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLKICKINGBYLENGTH(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1451,7 +1556,10 @@ def cdlladderbottom(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLLADDERBOTTOM(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1490,7 +1598,10 @@ def cdllongleggeddoji(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLLONGLEGGEDDOJI(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1529,7 +1640,10 @@ def cdllongline(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLLONGLINE(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1568,7 +1682,10 @@ def cdlmarubozu(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLMARUBOZU(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1607,7 +1724,10 @@ def cdlmatchinglow(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLMATCHINGLOW(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1648,10 +1768,10 @@ def cdlmathold(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLMATHOLD(
-        df[opencol].values,
-        df[highcol].values,
-        df[lowcol].values,
-        df[closecol].values,
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
         penetration,
     )
     return pd.DataFrame(
@@ -1693,10 +1813,10 @@ def cdlmorningdojistar(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLMORNINGDOJISTAR(
-        df[opencol].values,
-        df[highcol].values,
-        df[lowcol].values,
-        df[closecol].values,
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
         penetration,
     )
     return pd.DataFrame(
@@ -1738,10 +1858,10 @@ def cdlmorningstar(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLMORNINGSTAR(
-        df[opencol].values,
-        df[highcol].values,
-        df[lowcol].values,
-        df[closecol].values,
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
         penetration,
     )
     return pd.DataFrame(
@@ -1781,7 +1901,10 @@ def cdlonneck(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLONNECK(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1820,7 +1943,10 @@ def cdlpiercing(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLPIERCING(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1859,7 +1985,10 @@ def cdlrickshawman(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLRICKSHAWMAN(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1898,7 +2027,10 @@ def cdlrisefall3methods(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLRISEFALL3METHODS(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1937,7 +2069,10 @@ def cdlseparatinglines(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLSEPARATINGLINES(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -1976,7 +2111,10 @@ def cdlshootingstar(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLSHOOTINGSTAR(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2015,7 +2153,10 @@ def cdlshortline(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLSHORTLINE(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2054,7 +2195,10 @@ def cdlspinningtop(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLSPINNINGTOP(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2093,7 +2237,10 @@ def cdlstalledpattern(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLSTALLEDPATTERN(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2132,7 +2279,10 @@ def cdlsticksandwich(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLSTICKSANDWICH(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2171,7 +2321,10 @@ def cdltakuri(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLTAKURI(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2210,7 +2363,10 @@ def cdltasukigap(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLTASUKIGAP(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2249,7 +2405,10 @@ def cdlthrusting(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLTHRUSTING(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2288,7 +2447,10 @@ def cdltristar(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLTRISTAR(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2327,7 +2489,10 @@ def cdlunique3river(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLUNIQUE3RIVER(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2366,7 +2531,10 @@ def cdlupsidegap2crows(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLUPSIDEGAP2CROWS(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
@@ -2405,7 +2573,10 @@ def cdlxsidegap3methods(
     """
     df = client.chartDF(symbol, timeframe)
     val = t.CDLXSIDEGAP3METHODS(
-        df[opencol].values, df[highcol].values, df[lowcol].values, df[closecol].values
+        df[opencol].values.astype(float),
+        df[highcol].values.astype(float),
+        df[lowcol].values.astype(float),
+        df[closecol].values.astype(float),
     )
     return pd.DataFrame(
         {
