@@ -1,3 +1,11 @@
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
+
 import pandas as pd
 from mock import MagicMock
 
@@ -26,7 +34,7 @@ class TestAPI:
         bollinger(C, S, "6m")
 
     def test_emasma(self):
-        from pyEX.studies import ema, sma, dema
+        from pyEX.studies import dema, ema, sma
 
         ema(C, S)
         ema(C, S, periods=30)
