@@ -1,5 +1,19 @@
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
+
+import atexit
+import pickle
+
 # for Coverage
-from mock import patch
+from mock import MagicMock, patch
+
+atexit.register = MagicMock()
+pickle.dump = MagicMock()
 
 
 class TestEconomic:
@@ -7,7 +21,7 @@ class TestEconomic:
         from pyEX import Client
 
         c = Client("test")
-        with patch("pyEX.common._getJsonIEXCloud"), patch("pickle.dump"):
+        with patch("pyEX.common.urls._getIEXCloud"):
             c.us30()
             c.us15()
             c.us5()
