@@ -1,14 +1,22 @@
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
+
 # for Coverage
-from mock import patch, MagicMock
+from mock import MagicMock, patch
 
 SYMBOL = "aapl"
 
 
 class TestAll:
     def test_other(self):
-        from pyEX.marketdata.sse import _runSSE, DeepChannelsSSE
+        from pyEX.streaming.sse import DeepChannelsSSE, _runSSE
 
-        with patch("pyEX.marketdata.sse._streamSSE"):
+        with patch("pyEX.streaming.sse._streamSSE"):
             # coverage
             _runSSE("test")
             _runSSE("test", symbols=["test"])
