@@ -1,6 +1,15 @@
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
+
 # for Coverage
 import time
-from mock import patch, MagicMock
+
+from mock import MagicMock, patch
 
 SYMBOL = "aapl"
 
@@ -12,7 +21,7 @@ class TestPoints:
     def test_points(self):
         from pyEX import points
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             points()
@@ -22,7 +31,7 @@ class TestPoints:
     def test_pointsDF(self):
         from pyEX import pointsDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
