@@ -1,5 +1,19 @@
+# *****************************************************************************
+#
+# Copyright (c) 2020, the pyEX authors.
+#
+# This file is part of the pyEX library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
+
+import atexit
+import pickle
+
 # for Coverage
-from mock import patch, MagicMock
+from mock import MagicMock, patch
+
+atexit.register = MagicMock()
+pickle.dump = MagicMock()
 
 
 class TestAll:
@@ -23,15 +37,15 @@ class TestAll:
 
     def test_symbols(self):
         from pyEX.refdata import (
-            symbols,
+            fxSymbols,
             iexSymbols,
+            internationalSymbols,
             mutualFundSymbols,
             otcSymbols,
-            internationalSymbols,
-            fxSymbols,
+            symbols,
         )
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             symbols()
@@ -47,10 +61,10 @@ class TestAll:
             fxSymbols()
 
     def test_symbolsDF(self):
-        from pyEX.refdata import symbolsDF
         from pyEX import Client
+        from pyEX.refdata import symbolsDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -80,7 +94,7 @@ class TestAll:
     def test_calendar(self):
         from pyEX import Client
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -91,7 +105,7 @@ class TestAll:
     def test_calendarDF(self):
         from pyEX import Client
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -102,7 +116,7 @@ class TestAll:
     def test_corporateActions(self):
         from pyEX.refdata import corporateActions
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             corporateActions()
@@ -111,7 +125,7 @@ class TestAll:
     def test_corporateActionsDF(self):
         from pyEX.refdata import corporateActionsDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -120,7 +134,7 @@ class TestAll:
     def test_dividends(self):
         from pyEX.refdata import refDividends
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             refDividends()
@@ -129,7 +143,7 @@ class TestAll:
     def test_dividendsDF(self):
         from pyEX.refdata import refDividendsDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -138,7 +152,7 @@ class TestAll:
     def test_nextDayExtDate(self):
         from pyEX.refdata import nextDayExtDate
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             nextDayExtDate()
@@ -147,7 +161,7 @@ class TestAll:
     def test_nextDayExtDateDF(self):
         from pyEX.refdata import nextDayExtDateDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -156,7 +170,7 @@ class TestAll:
     def test_directory(self):
         from pyEX.refdata import directory
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             directory()
@@ -165,7 +179,7 @@ class TestAll:
     def test_directoryDF(self):
         from pyEX.refdata import directoryDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -174,7 +188,7 @@ class TestAll:
     def test_sectors(self):
         from pyEX.refdata import sectors
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             sectors()
@@ -182,7 +196,7 @@ class TestAll:
     def test_sectorsDF(self):
         from pyEX.refdata import sectorsDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -191,7 +205,7 @@ class TestAll:
     def test_exchanges(self):
         from pyEX.refdata import exchanges, internationalExchanges
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             exchanges()
@@ -200,7 +214,7 @@ class TestAll:
     def test_exchangesDF(self):
         from pyEX.refdata import exchangesDF, internationalExchangesDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -210,7 +224,7 @@ class TestAll:
     def test_figi(self):
         from pyEX.refdata import figi
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             figi("")
@@ -218,7 +232,7 @@ class TestAll:
     def test_figiDF(self):
         from pyEX.refdata import figiDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
@@ -227,7 +241,7 @@ class TestAll:
     def test_tags(self):
         from pyEX.refdata import tags
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             tags()
@@ -235,7 +249,7 @@ class TestAll:
     def test_tagsDF(self):
         from pyEX.refdata import tagsDF
 
-        with patch("requests.get") as mock, patch("pickle.dump"):
+        with patch("requests.get") as mock:
             mock.return_value = MagicMock()
             mock.return_value.status_code = 200
             mock.return_value.json = MagicMock(return_value=[])
